
# THIS FILE IS GENERATED FROM OASYS SETUP.PY
short_version = '1.2.18'
version = '1.2.18'
full_version = '1.2.18'
git_revision = '1b151acbafd3a78c0b4cba319800f67812a28d91'
release = True

if not release:
    version = full_version
    short_version += ".dev"
